==> openflowplugin-extension-nicira-0.7.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/update/flow/input/original/flow/instructions/instruction/instruction/write/actions/_case/write/actions/action/action/NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.flow.input.original.flow.instructions.instruction.instruction.write.actions._case.write.actions.action.action;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.dec.nsh.ttl.grouping.NxDecNshTtl;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder} instances.
 *
 * @see NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder
 *
 */
public class NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder implements Builder<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase> {

    private NxDecNshTtl _nxDecNshTtl;


    Map<Class<? extends Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>>, Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>> augmentation = Collections.emptyMap();

    public NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder() {
    }
    public NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping arg) {
        this._nxDecNshTtl = arg.getNxDecNshTtl();
    }

    public NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder(NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase base) {
        this._nxDecNshTtl = base.getNxDecNshTtl();
        if (base instanceof NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseImpl) {
            NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseImpl impl = (NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>>, Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>> aug =((AugmentationHolder<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping) {
            this._nxDecNshTtl = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping)arg).getNxDecNshTtl();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping]");
    }

    public NxDecNshTtl getNxDecNshTtl() {
        return _nxDecNshTtl;
    }
    
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder setNxDecNshTtl(final NxDecNshTtl value) {
        this._nxDecNshTtl = value;
        return this;
    }
    
    public NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder addAugmentation(Class<? extends Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>> augmentationType, Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder removeAugmentation(Class<? extends Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase build() {
        return new NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseImpl(this);
    }

    private static final class NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseImpl implements NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase {
    
        private final NxDecNshTtl _nxDecNshTtl;
    
        private Map<Class<? extends Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>>, Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>> augmentation = Collections.emptyMap();
    
        NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseImpl(NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder base) {
            this._nxDecNshTtl = base.getNxDecNshTtl();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase> getImplementedInterface() {
            return NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase.class;
        }
    
        @Override
        public NxDecNshTtl getNxDecNshTtl() {
            return _nxDecNshTtl;
        }
        
        @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
        @Override
        public <E$$ extends Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>> E$$ augmentation(Class<E$$> augmentationType) {
            return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxDecNshTtl);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase other = (NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase)obj;
            if (!Objects.equals(_nxDecNshTtl, other.getNxDecNshTtl())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseImpl otherImpl = (NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>>, Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase");
            CodeHelpers.appendValue(helper, "_nxDecNshTtl", _nxDecNshTtl);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.8.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/update/flow/input/original/flow/instructions/instruction/instruction/write/actions/_case/write/actions/action/action/NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.flow.input.original.flow.instructions.instruction.instruction.write.actions._case.write.actions.action.action;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.dec.nsh.ttl.grouping.NxDecNshTtl;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder} instances.
 *
 * @see NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder
 *
 */
public class NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder implements Builder<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase> {

    private NxDecNshTtl _nxDecNshTtl;


    Map<Class<? extends Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>>, Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>> augmentation = Collections.emptyMap();

    public NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder() {
    }
    public NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping arg) {
        this._nxDecNshTtl = arg.getNxDecNshTtl();
    }

    public NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder(NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>>, Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>> aug =((AugmentationHolder<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._nxDecNshTtl = base.getNxDecNshTtl();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping) {
            this._nxDecNshTtl = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping)arg).getNxDecNshTtl();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping]");
    }

    public NxDecNshTtl getNxDecNshTtl() {
        return _nxDecNshTtl;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder setNxDecNshTtl(final NxDecNshTtl value) {
        this._nxDecNshTtl = value;
        return this;
    }
    
    public NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder addAugmentation(Class<? extends Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>> augmentationType, Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder removeAugmentation(Class<? extends Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase build() {
        return new NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseImpl(this);
    }

    private static final class NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseImpl
        extends AbstractAugmentable<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>
        implements NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase {
    
        private final NxDecNshTtl _nxDecNshTtl;
    
        NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseImpl(NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseBuilder base) {
            super(base.augmentation);
            this._nxDecNshTtl = base.getNxDecNshTtl();
        }
    
        @Override
        public Class<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase> getImplementedInterface() {
            return NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase.class;
        }
    
        @Override
        public NxDecNshTtl getNxDecNshTtl() {
            return _nxDecNshTtl;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxDecNshTtl);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase other = (NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase)obj;
            if (!Objects.equals(_nxDecNshTtl, other.getNxDecNshTtl())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseImpl otherImpl = (NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCaseImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>>, Augmentation<NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxActionDecNshTtlRpcUpdateFlowOriginalWriteActionsCase");
            CodeHelpers.appendValue(helper, "_nxDecNshTtl", _nxDecNshTtl);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
